@@ -575,7 +575,7 @@ mod tests {
         } = create_genesis_config(10_000);
         let bob = Keypair::new();
         let bob_pubkey = bob.pubkey();
-        let bank = Bank::new(&genesis_config);
+        let bank = Bank::new_for_tests(&genesis_config);
         let blockhash = bank.last_blockhash();
         let bank_forks = Arc::new(RwLock::new(BankForks::new(bank)));
         let rpc_subscriptions = Arc::new(RpcSubscriptions::new_for_tests(
@@ -700,7 +700,7 @@ mod tests {
             ..
         } = create_genesis_config(10_000);
         let bob_pubkey = solana_sdk::pubkey::new_rand();
-        let bank = Bank::new(&genesis_config);
+        let bank = Bank::new_for_tests(&genesis_config);
         let blockhash = bank.last_blockhash();
         let bank_forks = Arc::new(RwLock::new(BankForks::new(bank)));
 
@@ -713,7 +713,7 @@ mod tests {
         let tx = system_transaction::transfer(&alice, &bob_pubkey, 20, blockhash);
         let req = format!(
             r#"{{"jsonrpc":"2.0","id":1,"method":"signatureSubscribe","params":["{}"]}}"#,
-            tx.signatures[0].to_string()
+            tx.signatures[0]
         );
         let _res = io.handle_request_sync(&req);
 
@@ -750,7 +750,7 @@ mod tests {
         let from = Keypair::new();
         let stake_account = Keypair::new();
         let stake_program_id = stake::program::id();
-        let bank = Bank::new(&genesis_config);
+        let bank = Bank::new_for_tests(&genesis_config);
         let blockhash = bank.last_blockhash();
         let bank_forks = Arc::new(RwLock::new(BankForks::new(bank)));
         let bank0 = bank_forks.read().unwrap().get(0).unwrap().clone();
@@ -867,7 +867,7 @@ mod tests {
         } = create_genesis_config(10_000);
 
         let nonce_account = Keypair::new();
-        let bank = Bank::new(&genesis_config);
+        let bank = Bank::new_for_tests(&genesis_config);
         let blockhash = bank.last_blockhash();
         let bank_forks = Arc::new(RwLock::new(BankForks::new(bank)));
         let bank0 = bank_forks.read().unwrap().get(0).unwrap().clone();
@@ -958,7 +958,9 @@ mod tests {
         let bob_pubkey = solana_sdk::pubkey::new_rand();
 
         let GenesisConfigInfo { genesis_config, .. } = create_genesis_config(10_000);
-        let bank_forks = Arc::new(RwLock::new(BankForks::new(Bank::new(&genesis_config))));
+        let bank_forks = Arc::new(RwLock::new(BankForks::new(Bank::new_for_tests(
+            &genesis_config,
+        ))));
 
         let mut io = IoHandler::<()>::default();
         let subscriptions = Arc::new(RpcSubscriptions::default_with_bank_forks(bank_forks));
@@ -968,7 +970,7 @@ mod tests {
 
         let req = format!(
             r#"{{"jsonrpc":"2.0","id":1,"method":"accountSubscribe","params":["{}"]}}"#,
-            bob_pubkey.to_string()
+            bob_pubkey
         );
         let _res = io.handle_request_sync(&req);
 
@@ -999,7 +1001,7 @@ mod tests {
             mint_keypair: alice,
             ..
         } = create_genesis_config(10_000);
-        let bank = Bank::new(&genesis_config);
+        let bank = Bank::new_for_tests(&genesis_config);
         let blockhash = bank.last_blockhash();
         let bank_forks = Arc::new(RwLock::new(BankForks::new(bank)));
         let bob = Keypair::new();
@@ -1046,7 +1048,7 @@ mod tests {
             mint_keypair: alice,
             ..
         } = create_genesis_config(10_000);
-        let bank = Bank::new(&genesis_config);
+        let bank = Bank::new_for_tests(&genesis_config);
         let blockhash = bank.last_blockhash();
         let bank_forks = Arc::new(RwLock::new(BankForks::new(bank)));
         let bank0 = bank_forks.read().unwrap().get(0).unwrap().clone();
@@ -1124,7 +1126,7 @@ mod tests {
     #[serial]
     fn test_slot_subscribe() {
         let GenesisConfigInfo { genesis_config, .. } = create_genesis_config(10_000);
-        let bank = Bank::new(&genesis_config);
+        let bank = Bank::new_for_tests(&genesis_config);
         let bank_forks = Arc::new(RwLock::new(BankForks::new(bank)));
         let rpc_subscriptions = Arc::new(RpcSubscriptions::default_with_bank_forks(bank_forks));
         let (rpc, mut receiver) = rpc_pubsub_service::test_connection(&rpc_subscriptions);
@@ -1152,7 +1154,7 @@ mod tests {
     #[serial]
     fn test_slot_unsubscribe() {
         let GenesisConfigInfo { genesis_config, .. } = create_genesis_config(10_000);
-        let bank = Bank::new(&genesis_config);
+        let bank = Bank::new_for_tests(&genesis_config);
         let bank_forks = Arc::new(RwLock::new(BankForks::new(bank)));
         let rpc_subscriptions = Arc::new(RpcSubscriptions::default_with_bank_forks(bank_forks));
         let (rpc, mut receiver) = rpc_pubsub_service::test_connection(&rpc_subscriptions);
@@ -1190,7 +1192,7 @@ mod tests {
             vec![100; validator_voting_keypairs.len()],
         );
         let exit = Arc::new(AtomicBool::new(false));
-        let bank = Bank::new(&genesis_config);
+        let bank = Bank::new_for_tests(&genesis_config);
         let bank_forks = Arc::new(RwLock::new(BankForks::new(bank)));
 
         // Setup Subscriptions
@@ -1224,7 +1226,7 @@ mod tests {
     #[serial]
     fn test_vote_unsubscribe() {
         let GenesisConfigInfo { genesis_config, .. } = create_genesis_config(10_000);
-        let bank = Bank::new(&genesis_config);
+        let bank = Bank::new_for_tests(&genesis_config);
         let bank_forks = Arc::new(RwLock::new(BankForks::new(bank)));
         let rpc_subscriptions = Arc::new(RpcSubscriptions::default_with_bank_forks(bank_forks));
         let (rpc, _receiver) = rpc_pubsub_service::test_connection(&rpc_subscriptions);
