@@ -210,9 +210,10 @@ impl TestBroadcastReceiver {
                     }
                 }
                 Err(TryRecvError::Empty) => {
-                    if started.elapsed() > timeout {
-                        panic!("TestBroadcastReceiver: no data, timeout reached");
-                    }
+                    assert!(
+                        started.elapsed() <= timeout,
+                        "TestBroadcastReceiver: no data, timeout reached"
+                    );
                     sleep(Duration::from_millis(50));
                 }
                 Err(err) => panic!("broadcast receiver error: {}", err),
@@ -391,7 +392,7 @@ mod tests {
         let pubsub_addr = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(0, 0, 0, 0)), 0);
         let exit = Arc::new(AtomicBool::new(false));
         let GenesisConfigInfo { genesis_config, .. } = create_genesis_config(10_000);
-        let bank = Bank::new(&genesis_config);
+        let bank = Bank::new_for_tests(&genesis_config);
         let bank_forks = Arc::new(RwLock::new(BankForks::new(bank)));
         let optimistically_confirmed_bank =
             OptimisticallyConfirmedBank::locked_from_bank_forks_root(&bank_forks);
